## Steps to running GitBucket

- download gitbucket.war from https://github.com/gitbucket/gitbucket/releases. (tested version is 4.12)
- run `java -jar gitbucket.war`
    - It listen on 8080 port.
    - It creates data directory to ~/.gitbucket
    - There is only admin user by id:root / pw:root

## Steps to initialize GitBucket data. 

- run `python3 init.py`
